import React from 'react'
import Avatar from '@mui/material/Avatar'
import { connect } from 'react-redux'

import { stringColor } from '../../helpers'
import { backURL } from '../../constants'

function getUrl(obj) {
    if (obj.localUrl) {
        return obj.localUrl
    } else if (obj.avatar?.url) {
        return backURL + obj.avatar?.url
    } else {
        return false
    }
}

export const UserAvatar = ({ profile, bigSize = false }) => {
    return (
        <>
            {getUrl(profile) ? (
                <Avatar
                    className={`${bigSize ? 'big' : 'small'}`}
                    alt={profile.nick || profile.login}
                    src={getUrl(profile)}
                />
            ) : (
                <Avatar
                    className={`${bigSize ? 'big' : 'small'}`}
                    {...stringColor.stringAvatar(profile.nick || profile.login)}
                />
            )}
        </>
    )
}
export const CMyAvatar = connect((state) => ({
    profile: state.promise.myProfile?.payload || {},
}))(UserAvatar)

export const ChatAvatar = ({ chat, bigSize = false }) => {
    return (
        <>
            {getUrl(chat) ? (
                <Avatar
                    className={`${bigSize ? 'big' : 'small'}`}
                    alt={chat.title}
                    src={getUrl(chat)}
                />
            ) : (
                <Avatar
                    className={`${bigSize ? 'big' : 'small'}`}
                    {...stringColor.stringAvatar(chat.title)}
                />
            )}
        </>
    )
}
