import React, { useContext } from 'react'
import { useTheme } from '@mui/material/styles'
import useMediaQuery from '@mui/material/useMediaQuery'
import IconButton from '@mui/material/IconButton'
import ArrowBackIcon from '@mui/icons-material/ArrowBack'
import { Link } from 'react-router-dom'
import { connect } from 'react-redux'
import './ChatMngHeader.scss'

import { AdaptiveContext } from '../../App'
import { CChatModal } from '..'
import { CChatMenu } from './ChatMenu'
import { ChatMinInfo } from './ChatMinInfo'

const ChatMngHeader = ({ chats, chatId }) => {
    const chat = chats[chatId]

    const theme = useTheme()
    const matches = useMediaQuery(theme.breakpoints.up('sm'))

    const contextObj = useContext(AdaptiveContext)
    return (
        <div className="chatMngBody">
            {matches || (
                <div className="blockMobile">
                    <Link
                        className="unstyledLink"
                        to={`/main`}
                        onClick={() => {
                            contextObj.setAside(true)
                        }}
                    >
                        <IconButton style={{ color: '#fff' }}>
                            <ArrowBackIcon />
                        </IconButton>
                    </Link>
                </div>
            )}

            <CChatModal
                key={chatId}
                create={false}
                chat={chat}
                render={ChatMinInfo}
            />

            <div className="blockRight">
                <CChatMenu chatId={chatId} />
            </div>
        </div>
    )
}
export const CChatMngHeader = connect((state) => ({
    chats: state.chats || [],
}))(ChatMngHeader)
