import React, { useEffect, useState } from 'react'
import Box from '@mui/material/Box'
import Modal from '@mui/material/Modal'
import Button from '@mui/material/Button'
import IconButton from '@mui/material/IconButton'
import Typography from '@mui/material/Typography'
import TextField from '@mui/material/TextField'
import CloseIcon from '@mui/icons-material/Close'
import List from '@mui/material/List'
import { useDropzone } from 'react-dropzone'
import { connect } from 'react-redux'
import CancelIcon from '@mui/icons-material/Cancel'
// import {ReactComponent as KickLogo} from '../assets/kick.svg'
import './ChatModal.scss'

import { ChatAvatar, CUserSearch, UserCard } from '..'
import { printStrReq } from '../../helpers'
import { actionSetChatInfo } from '../../actions'

const DelBtn = ({ onEvent }) => (
    <IconButton edge="end" onClick={onEvent}>
        <CancelIcon />
    </IconButton>
)

const ChatModal = ({
    minTitle = '2',
    chat,
    onСonfirm,
    titleError,
    myProfile,
    create,
    render,
}) => {
    const [open, setOpen] = useState(false)
    const handleOpen = () => setOpen(true)
    const handleClose = () => setOpen(false)

    const [title, setTitle] = useState(chat?.title || '')
    const [titleBlur, setTitleBlur] = useState(false)

    const [img, setImg] = useState(null)
    const { getRootProps, getInputProps } = useDropzone({
        accept: 'image/*',
        maxFiles: 1,
        onDrop: (acceptedFiles) => {
            setImg(acceptedFiles[0])
        },
    })

    const [members, setMembers] = useState(chat?.members || [myProfile])

    const onAddMember = (newMember) => {
        setMembers([...members, newMember])
    }
    const onDelMember = (i) => {
        setMembers(members.filter((el, index) => index !== i))
    }

    const [wrongAlert, setWrongAlert] = useState(false)

    useEffect(() => {
        if (titleError?.payload === null) {
            setWrongAlert(true)
        } else {
            setWrongAlert(false)
        }
    }, [titleError])

    useEffect(() => {
        setTitle(chat?.title || '')
        setImg(null)
        setMembers(chat?.members || [myProfile])
    }, [open])

    function prepareMembers(members) {
        const newMembers = []

        for (const member of members) {
            if (create) {
                if (member._id !== myProfile?._id) {
                    newMembers.push({ _id: member._id })
                }
            } else {
                newMembers.push({ _id: member._id })
            }
        }
        return newMembers
    }

    const OpenBtn = render
    return (
        <>
            <OpenBtn chat={chat} OPEN={handleOpen} />

            <Modal open={open} onClose={handleClose}>
                <Box className="styleModalParrent chatModalWrapp">
                    <Box className="modalHead">
                        <Box className="modalTitle">
                            <Typography variant="h6">
                                {chat?.owner?._id !== myProfile?._id && !create
                                    ? 'Информация (редактирование запрещено)'
                                    : create
                                    ? 'Создание чата'
                                    : 'Редактирование чата'}
                            </Typography>
                        </Box>

                        <Box className="modalClose">
                            <IconButton onClick={handleClose}>
                                <CloseIcon />
                            </IconButton>
                        </Box>
                    </Box>

                    <Box className="modalChatInfo">
                        <Box className="avatarBlock">
                            <section className="container">
                                <Box
                                    {...getRootProps({ className: 'dropzone' })}
                                    className="avatarBox avatarInModal"
                                >
                                    <ChatAvatar
                                        chat={{
                                            title: title,
                                            avatar: {
                                                url: chat?.avatar?.url || '',
                                            },
                                            localUrl:
                                                img && URL.createObjectURL(img),
                                        }}
                                        bigSize={true}
                                    />

                                    <input
                                        {...getInputProps()}
                                        type="file"
                                        name="media"
                                        id="mediaUser"
                                    />
                                    <Box className="avatarTitleBox">
                                        <Typography className="avatarTitle">
                                            Аватар
                                        </Typography>
                                    </Box>
                                </Box>
                            </section>
                        </Box>

                        <Box className="nameBlock">
                            <Typography className="nameTitle">
                                Название
                            </Typography>

                            <TextField
                                onChange={(e) => {
                                    setTitle(e.target.value)
                                }}
                                onBlur={() => {
                                    setTitleBlur(true)
                                }}
                                onFocus={() => {
                                    setTitleBlur(false)
                                }}
                                error={
                                    titleBlur
                                        ? title?.length >= minTitle
                                            ? false
                                            : true
                                        : false
                                }
                                helperText={printStrReq(title, minTitle)}
                                inputProps={{
                                    maxLength: 50,
                                }}
                                variant="standard"
                                margin="none"
                                fullWidth
                                id="titleChat"
                                label=""
                                name="title"
                                defaultValue={title}
                                className="nameInput"
                            />
                        </Box>
                    </Box>

                    <Box className="modalMembers">
                        <Box className="membersHead">
                            <Typography className="membersTitle">
                                Добавить участников
                            </Typography>
                        </Box>

                        <Box className="membersBody">
                            <Box className="currentMembersBlock">
                                <Box className="currentMembersHead">
                                    <Typography className="currentMembersTitle">
                                        Сейчас в чате
                                    </Typography>
                                </Box>

                                <Box className="currentMembersBody">
                                    <List className="currentMembersList">
                                        {members.map((member, i) => (
                                            <UserCard
                                                key={member._id || i}
                                                user={member}
                                                render={DelBtn}
                                                onAction={() => onDelMember(i)}
                                            />
                                        ))}
                                    </List>
                                </Box>
                            </Box>

                            <CUserSearch
                                open={open}
                                alreadySearched={members}
                                onAdd={onAddMember}
                            />
                        </Box>
                    </Box>

                    <Box className="modalSubmit">
                        {wrongAlert && (
                            <Typography
                                component="p"
                                variant="body2"
                                className="alertBlock"
                            >
                                Ошибка создания
                            </Typography>
                        )}

                        <Box className="btnBlock">
                            <Button
                                variant="contained"
                                disabled={
                                    title?.length < minTitle
                                        ? true
                                        : chat?.owner?._id !== myProfile?._id &&
                                          !create
                                        ? true
                                        : false
                                }
                                onClick={() => {
                                    onСonfirm(
                                        'media',
                                        img,
                                        title,
                                        prepareMembers(members),
                                        chat?._id
                                    )
                                    handleClose()
                                }}
                            >
                                Применить
                            </Button>
                        </Box>
                    </Box>
                </Box>
            </Modal>
        </>
    )
}
export const CChatModal = connect(
    (state) => ({
        chatError: state.promise.updateChat || {},
        myProfile: state.promise.myProfile?.payload || {},
    }),
    { onСonfirm: actionSetChatInfo }
)(ChatModal)
