import React, { useState } from 'react'
import FileDownloadIcon from '@mui/icons-material/FileDownload'
import Popover from '@mui/material/Popover'
import List from '@mui/material/List'
import ListItemButton from '@mui/material/ListItemButton'
import { connect } from 'react-redux'

import './Msg.scss'

import { dateFromStamp, stringColor, sortMediaArr } from '../../helpers'
import { backURL } from '../../constants'
import { UserAvatar, CMyAvatar } from '..'

const Msg = ({ msg, myProfile, onEdit }) => {
    const myId = myProfile?._id || null
    const myLogin = myProfile?.login || null
    const myNick = myProfile?.nick || null

    const { text, owner, media, createdAt, nextMsg } = msg
    const { nick, login } = owner

    const allMedia = sortMediaArr(media)

    const [anchorEl, setAnchorEl] = useState(null)
    const [top, setTop] = useState(0)
    const [left, setLeft] = useState(0)

    const handleClick = (e) => {
        e.preventDefault()
        setTop(e.clientY)
        setLeft(e.clientX)
        setAnchorEl(e.currentTarget)
    }

    const handleClose = () => {
        setAnchorEl(null)
    }

    const open = !!anchorEl
    const myMsg = myId === owner._id

    const nameColor = {
        color: myMsg ? '#000' : stringColor.stringToColor(nick || login),
    }

    // const matchLink = text.match(linkRegEx)
    // const matchYoutube = text.match(youtubeRegEx)
    // console.log(matchLink, matchYoutube)

    return (
        <>
            <Popover
                open={open}
                anchorEl={anchorEl}
                onClose={handleClose}
                anchorReference={'anchorPosition'}
                anchorPosition={{
                    top: top,
                    left: left,
                }}
            >
                <List
                    sx={{
                        width: '100%',
                        maxWidth: 300,
                        bgcolor: 'background.paper',
                    }}
                >
                    <ListItemButton
                        onClick={() => {
                            handleClose()
                        }}
                    >
                        Ответить
                    </ListItemButton>

                    {myMsg && (
                        <ListItemButton
                            onClick={() => {
                                onEdit({ ...msg })
                                handleClose()
                            }}
                        >
                            Редактировать
                        </ListItemButton>
                    )}
                </List>
            </Popover>

            <div
                onContextMenu={handleClick}
                className={`msgBlock ${
                    myMsg
                        ? nextMsg?.owner?._id === owner._id
                            ? 'myMsg nearMsg'
                            : 'myMsg distantMsg'
                        : nextMsg?.owner?._id === owner._id
                        ? 'otherMsg nearMsg'
                        : 'otherMsg distantMsg'
                }`}
            >
                <div className="avBlock">
                    {(nextMsg?.owner?._id === owner._id &&
                        nextMsg?.createdAt - createdAt < 600000) ||
                        (myMsg ? (
                            <CMyAvatar />
                        ) : (
                            <UserAvatar profile={owner} />
                        ))}
                </div>

                <div className={`bodyBlock ${myMsg && 'myBodyBlock'}`}>
                    <div className="nameBlock" style={nameColor}>
                        {myMsg ? myNick || myLogin : nick || login}
                    </div>

                    <div className="contentBlock">
                        {Object.keys(allMedia).length > 0 && (
                            <div className="mediaBlock">
                                {Object.keys(allMedia).map((key) => (
                                    <div key={key}>
                                        {(key === 'image' &&
                                            allMedia[key].map((mediaObj) => (
                                                <img
                                                    key={mediaObj.url}
                                                    className="imgStyle"
                                                    src={backURL + mediaObj.url}
                                                    type={mediaObj.type}
                                                />
                                            ))) ||
                                            (key === 'video' &&
                                                allMedia[key].map(
                                                    (mediaObj) => (
                                                        <video
                                                            key={mediaObj.url}
                                                            className="imgStyle"
                                                            src={
                                                                backURL +
                                                                mediaObj.url
                                                            }
                                                            controls
                                                            preload={'metadata'}
                                                        ></video>
                                                    )
                                                )) ||
                                            (key === 'audio' &&
                                                allMedia[key].map(
                                                    (mediaObj) => (
                                                        <div key={mediaObj.url}>
                                                            <audio
                                                                src={
                                                                    backURL +
                                                                    mediaObj.url
                                                                }
                                                                controls
                                                            ></audio>
                                                        </div>
                                                    )
                                                )) ||
                                            allMedia[key].map((mediaObj) => (
                                                <a
                                                    key={mediaObj.url}
                                                    href={
                                                        backURL + mediaObj.url
                                                    }
                                                    download={
                                                        mediaObj.originalFileName
                                                    }
                                                    className="downloadStyle"
                                                >
                                                    <div className="imgDownload">
                                                        <FileDownloadIcon
                                                            style={{
                                                                fontSize: 35,
                                                                color: '#ddd',
                                                            }}
                                                        />
                                                    </div>
                                                    <div className="textDownload">
                                                        {
                                                            mediaObj.originalFileName
                                                        }
                                                    </div>
                                                </a>
                                            ))}
                                    </div>
                                ))}
                            </div>
                        )}

                        <pre className="textBlock">{text}</pre>
                    </div>

                    <div className="dateBlock">{dateFromStamp(createdAt)}</div>
                </div>
            </div>
        </>
    )
}
export const CMsg = connect((state) => ({
    myProfile: state.promise.myProfile?.payload || {},
}))(Msg)
