import React, { useEffect, useState } from 'react'
import Box from '@mui/material/Box'
import Modal from '@mui/material/Modal'
import Button from '@mui/material/Button'
import IconButton from '@mui/material/IconButton'
import Typography from '@mui/material/Typography'
import TextField from '@mui/material/TextField'
import CloseIcon from '@mui/icons-material/Close'
import { connect } from 'react-redux'
import './ProfileModal.scss'

import { passReq } from '../../helpers'
import { actionSetUserPass } from '../../actions'

const PassModal = ({ onСonfirm, regError }) => {
    const [open, setOpen] = useState(false)
    const handleOpen = () => {
        setOpen(true)
    }
    const handleClose = () => {
        setOpen(false)
    }

    const [pass, setPass] = useState('')
    const [passBlur, setPassBlur] = useState(false)

    const [pass2, setPass2] = useState('')
    const [pass2Blur, setPass2Blur] = useState(false)

    const [wrongAlert, setWrongAlert] = useState(false)

    useEffect(() => {
        if (regError?.payload === null) {
            setWrongAlert(true)
        } else {
            setWrongAlert(false)
        }
    }, [regError])

    return (
        <>
            <Button variant="text" color="error" onClick={handleOpen}>
                Новый пароль
            </Button>

            <Modal hideBackdrop open={open} onClose={handleClose}>
                <Box className="styleModalParrent passModalWrapp">
                    <Box className="closeBlock">
                        <IconButton onClick={handleClose}>
                            <CloseIcon />
                        </IconButton>
                    </Box>

                    <Box className="passBlock">
                        <Typography variant="body1">
                            Введите новый пароль
                        </Typography>
                        <TextField
                            onChange={(e) => {
                                e.target.value = e.target.value.trim()
                                setPass(e.target.value.trim())
                            }}
                            onBlur={() => {
                                setPassBlur(true)
                            }}
                            onFocus={() => {
                                setPassBlur(false)
                            }}
                            error={
                                passBlur
                                    ? passReq.checkPass(pass)
                                        ? false
                                        : true
                                    : false
                            }
                            helperText={passReq.printPassReq(pass)}
                            inputProps={{
                                maxLength: 100,
                            }}
                            required
                            variant="standard"
                            margin="none"
                            fullWidth
                            name="password"
                            label=""
                            type="password"
                            id="passwordUser"
                            className="passInput"
                        />
                    </Box>

                    <Box className="passBlock">
                        <Typography variant="body1">
                            Повторите новый пароль
                        </Typography>
                        <TextField
                            onChange={(e) => {
                                e.target.value = e.target.value.trim()
                                setPass2(e.target.value.trim())
                            }}
                            onBlur={() => {
                                setPass2Blur(true)
                            }}
                            onFocus={() => {
                                setPass2Blur(false)
                            }}
                            error={
                                pass2Blur
                                    ? passReq.checkPass(pass2)
                                        ? false
                                        : true
                                    : false
                            }
                            helperText={passReq.printPassReq(pass2)}
                            inputProps={{
                                maxLength: 100,
                            }}
                            required
                            variant="standard"
                            margin="none"
                            fullWidth
                            name="password"
                            label=""
                            type="password"
                            id="passwordUser2"
                            className="passInput"
                        />
                    </Box>

                    {wrongAlert && (
                        <Typography
                            component="p"
                            variant="body2"
                            className="alertBlock"
                        >
                            Неверный пароль
                        </Typography>
                    )}

                    <Box className="btnBlock">
                        <Button
                            variant="contained"
                            disabled={
                                passReq.checkPass(pass) && pass === pass2
                                    ? false
                                    : true
                            }
                            onClick={() => {
                                onСonfirm(pass)
                                handleClose()
                            }}
                        >
                            Изменить
                        </Button>
                    </Box>
                </Box>
            </Modal>
        </>
    )
}
export const CPassModal = connect(
    (state) => ({ regError: state.promise.changePass || {} }),
    { onСonfirm: actionSetUserPass }
)(PassModal)
