import React, { useEffect, useState } from 'react'
import { useTheme } from '@mui/material/styles'
import useMediaQuery from '@mui/material/useMediaQuery'
import Box from '@mui/material/Box'
import Modal from '@mui/material/Modal'
import ListItem from '@mui/material/ListItem'
import ListItemText from '@mui/material/ListItemText'
import Button from '@mui/material/Button'
import IconButton from '@mui/material/IconButton'
import Typography from '@mui/material/Typography'
import TextField from '@mui/material/TextField'
import CloseIcon from '@mui/icons-material/Close'
import { connect } from 'react-redux'
import { useDropzone } from 'react-dropzone'
import './ProfileModal.scss'

import { CPassModal } from './PassModal'
import { UserAvatar } from '..'
import { printStrReq } from '../../helpers'
import { actionSetUserInfo } from '../../actions'

const ProfileModal = ({ minLog = '2', myProfile, onСonfirm, logError }) => {
    const [open, setOpen] = useState(false)

    const [login, setLogin] = useState(myProfile.login)
    const [logBlur, setLogBlur] = useState(false)
    const [nick, setNick] = useState(myProfile.nick)

    const [img, setImg] = useState(null)
    const { getRootProps, getInputProps } = useDropzone({
        accept: 'image/*',
        maxFiles: 1,
        onDrop: (acceptedFiles) => {
            setImg(acceptedFiles[0])
        },
    })

    const handleOpen = () => setOpen(true)
    const handleClose = () => setOpen(false)

    const [wrongAlert, setWrongAlert] = useState(false)

    useEffect(() => {
        if (logError?.payload === null) {
            setWrongAlert(true)
        } else {
            setWrongAlert(false)
        }
    }, [logError])

    const theme = useTheme()
    const matches = useMediaQuery(theme.breakpoints.up('sm'))
    return (
        <div>
            <ListItem button onClick={handleOpen}>
                <ListItemText primary={'Мой профиль'} />
            </ListItem>

            <Modal open={open} onClose={handleClose}>
                <Box className="styleModalParrent profileModalWrapp">
                    <Box className="closeBlock">
                        <IconButton onClick={handleClose}>
                            <CloseIcon />
                        </IconButton>
                    </Box>

                    <Box className="titleBlock">
                        <Typography variant="h5">Мой профиль</Typography>
                    </Box>

                    <Box className="avatarBlock">
                        <section className="container">
                            <Box
                                {...getRootProps({ className: 'dropzone' })}
                                className="avatarBox avatarInModal"
                            >
                                <UserAvatar
                                    profile={{
                                        login: login,
                                        nick: nick,
                                        avatar: {
                                            url: myProfile.avatar?.url || '',
                                        },
                                        localUrl:
                                            img && URL.createObjectURL(img),
                                    }}
                                    bigSize={true}
                                />

                                <input
                                    {...getInputProps()}
                                    type="file"
                                    name="media"
                                    id="mediaUser"
                                />

                                {matches && (
                                    <Box className="avatarTitle">
                                        Изменить аватар
                                    </Box>
                                )}
                            </Box>
                        </section>
                    </Box>

                    <Box className="nameBlock">
                        <Typography variant="body1">Изменить логин</Typography>
                        <TextField
                            onChange={(e) => {
                                e.target.value = e.target.value.trim()
                                setLogin(e.target.value)
                            }}
                            onBlur={() => {
                                setLogBlur(true)
                            }}
                            onFocus={() => {
                                setLogBlur(false)
                            }}
                            error={
                                logBlur
                                    ? login?.length >= minLog
                                        ? false
                                        : true
                                    : false
                            }
                            helperText={printStrReq(login, minLog)}
                            inputProps={{
                                maxLength: 25,
                            }}
                            variant="standard"
                            margin="none"
                            fullWidth
                            id="loginMain"
                            label=""
                            name="login"
                            defaultValue={login}
                            className="nameInput"
                        />
                    </Box>

                    <Box className="nameBlock">
                        <Typography variant="body1">Изменить ник</Typography>
                        <TextField
                            onChange={(e) => {
                                setNick(e.target.value)
                            }}
                            helperText={''}
                            variant="standard"
                            margin="none"
                            fullWidth
                            id="nickMain"
                            label=""
                            name="nick"
                            defaultValue={nick}
                            className="nameInput"
                        />
                    </Box>

                    <Box className="passModalBlock">
                        <CPassModal />
                    </Box>

                    {wrongAlert ? (
                        <Typography
                            component="p"
                            variant="body2"
                            className="alertBlock"
                        >
                            Логин уже существует
                        </Typography>
                    ) : (
                        <></>
                    )}

                    <Box className="btnBlock">
                        <Button
                            variant="contained"
                            disabled={login?.length >= minLog ? false : true}
                            onClick={() => {
                                onСonfirm('media', img, login, nick)
                                handleClose()
                            }}
                        >
                            Применить
                        </Button>
                    </Box>
                </Box>
            </Modal>
        </div>
    )
}
export const CProfileModal = connect(
    (state) => ({
        myProfile: state.promise?.myProfile?.payload || {},
        logError: state.promise.updateUser || {},
    }),
    { onСonfirm: actionSetUserInfo }
)(ProfileModal)
