import React, { useEffect, useRef } from 'react'
import TextareaAutosize from '@mui/base/TextareaAutosize'
import AttachFileIcon from '@mui/icons-material/AttachFile'
import CloseIcon from '@mui/icons-material/Close'
import { useDropzone } from 'react-dropzone'
import { SortableContainer, SortableElement } from 'react-sortable-hoc'
import { arrayMoveImmutable } from 'array-move'
import './SendingField.scss'

const SortableItem = SortableElement(({ onDelete, file }) => (
    <div className="thumb">
        <div className="closeBtn">
            <CloseIcon
                fontSize="small"
                sx={{ cursor: 'pointer' }}
                onClick={onDelete}
            />
        </div>
        <div className="thumbInner">
            {file.type &&
                (file.type.split('/')[0] === 'image' ? (
                    <img src={file.url} className="img" />
                ) : file.type.split('/')[0] === 'video' ? (
                    <video
                        autoPlay
                        muted
                        loop
                        src={file.url}
                        className="img"
                    ></video>
                ) : (
                    <div className="other">
                        <div className="othTitle">
                            {file.type.split('/')[0]}
                        </div>
                        <div className="othContent">{file.name}</div>
                    </div>
                ))}
        </div>
    </div>
))

const SortableList = SortableContainer(({ children }) => {
    return <div className="thumbsContainer">{children}</div>
})

export const MsgDropZone = ({
    setText,
    setFiles,
    setMsgId,
    files,
    text,
    onEnter,
}) => {
    const { getRootProps, getInputProps } = useDropzone({
        noKeyboard: true,
        onDrop: async (acceptedFiles) => {
            // console.log(acceptedFiles)
            await setFiles([
                ...files,
                ...acceptedFiles.map((file) =>
                    Object.assign(file, {
                        url: URL.createObjectURL(file),
                    })
                ),
            ])
        },
    })

    const onDelete = (i) => {
        setFiles((files) => files.filter((el, index) => index !== i))
    }

    const onSortEnd = ({ oldIndex, newIndex }) => {
        setFiles((files) => arrayMoveImmutable(files, oldIndex, newIndex))
    }

    // useEffect(() => {
    // // Make sure to revoke the data uris to avoid memory leaks
    // files.forEach(file => URL.revokeObjectURL(file.url));
    // }, [files]);
    const textArea = useRef(null)

    useEffect(() => {
        textArea.current.focus()
    })

    return (
        <>
            <section className="containerWrapp">
                <SortableList
                    onSortEnd={onSortEnd}
                    axis={'xy'}
                    pressDelay={100}
                >
                    {files.map((file, i) => {
                        // console.log(file)
                        if (file)
                            return (
                                <SortableItem
                                    key={file.url}
                                    index={i}
                                    file={file}
                                    onDelete={() => onDelete(i)}
                                    axis={'xy'}
                                />
                            )
                    })}
                </SortableList>

                <div
                    {...getRootProps({ className: 'dropzone' })}
                    className="inputContainer"
                >
                    <input
                        {...getInputProps()}
                        type="file"
                        name="media"
                        id="media"
                    />

                    <AttachFileIcon fontSize="large" className="attachFile" />

                    <TextareaAutosize
                        ref={textArea}
                        value={text}
                        minRows={4}
                        maxRows={10}
                        placeholder="Написать сообщение..."
                        className="textareaAutosize"
                        onClick={(e) => e.stopPropagation()}
                        onChange={(e) => setText(e.target.value)}
                        onKeyPress={(e) => {
                            if (e.key === 'Enter' && !e.shiftKey) {
                                e.preventDefault()
                                ;(text.match(/^\s*$/) && files.length === 0) ||
                                    onEnter()
                                setText('')
                                setFiles([])
                                setMsgId()
                            }
                        }}
                    />
                </div>
            </section>
        </>
    )
}
