import React, { useState, useEffect } from 'react'
import Box from '@mui/material/Box'
import Button from '@mui/material/Button'
import SendIcon from '@mui/icons-material/Send'
import { connect } from 'react-redux'
import './SendingField.scss'

import { MsgDropZone } from './MsgDropZone'
import { actionSendMsg } from '../../actions'
import { backURL } from '../../constants'

const SendingField = ({ chatId, onSend, msg }) => {
    const [text, setText] = useState(msg?.text || '')
    const [files, setFiles] = useState(
        msg?.media.map((mediaFile) => ({
            ...mediaFile,
            url: backURL + mediaFile.url,
        })) || []
    )
    const [msgId, setMsgId] = useState(msg?._id || null)

    useEffect(() => {
        setText(msg?.text || '')
        setFiles(
            msg?.media.map((mediaFile) => ({
                ...mediaFile,
                url: backURL + mediaFile.url,
            })) || []
        )
        setMsgId(msg?._id || null)
    }, [msg])

    return (
        <Box className="sendingField">
            <Box className="sendingBox">
                {msgId && (
                    <Box className="buttonEditBox">
                        <Button
                            className="buttonEdit"
                            variant="contained"
                            onClick={() => {
                                setText('')
                                setFiles([])
                                setMsgId()
                            }}
                        >
                            Отменить редактирование
                        </Button>
                    </Box>
                )}

                <MsgDropZone
                    setText={setText}
                    setFiles={setFiles}
                    setMsgId={setMsgId}
                    files={files}
                    text={text}
                    onEnter={() =>
                        onSend(chatId, text.trim(), 'media', files, msgId)
                    }
                />
            </Box>
            <Box className="buttonSendBox">
                <Button
                    className="buttonSend"
                    variant="contained"
                    endIcon={<SendIcon />}
                    onClick={() => {
                        ;(text.match(/^\s*$/) && files.length === 0) ||
                            onSend(chatId, text.trim(), 'media', files, msgId)
                        setText('')
                        setFiles([])
                        setMsgId()
                    }}
                >
                    Отправить
                </Button>
            </Box>
        </Box>
    )
}
export const CSendingField = connect(null, { onSend: actionSendMsg })(
    SendingField
)
