import React, { useEffect, useState } from 'react'
import List from '@mui/material/List'
import Box from '@mui/material/Box'
import IconButton from '@mui/material/IconButton'
import AddIcon from '@mui/icons-material/Add'
import { connect } from 'react-redux'
import './UserSearch.scss'

import { UserCard, SearchBlock } from '..'
import { actionFindUsers } from '../../actions'

const AddBtn = ({ onEvent }) => (
    <IconButton edge="end" onClick={onEvent}>
        <AddIcon />
    </IconButton>
)

const UserSearch = ({
    findedUsers,
    onSearch,
    alreadySearched = [],
    onAdd,
    open,
}) => {
    const [finded, setFinded] = useState([])
    const [input, setInput] = useState(null)

    useEffect(() => {
        let timeout
        if (input !== null) {
            timeout = setTimeout(() => {
                onSearch(input)
            }, 500)
        }
        return () => {
            clearTimeout(timeout)
        }
    }, [input])

    useEffect(() => {
        setFinded(findedUsers)
    }, [findedUsers])

    useEffect(() => {
        setInput(null)
        setFinded([])
    }, [open])

    return (
        <Box className="userSearchBox">
            <Box className="searchField">
                <SearchBlock setInput={setInput} text={'Найти пользователя'} />
            </Box>

            <Box className="usersBox">
                <List className="usersList">
                    {finded.map((user) => (
                        <UserCard
                            key={user._id}
                            user={user}
                            render={AddBtn}
                            onAction={() => onAdd(user)}
                            disabled={
                                !!alreadySearched.find(
                                    (searchedUser) =>
                                        searchedUser._id === user._id
                                )
                            }
                        />
                    ))}
                </List>
            </Box>
        </Box>
    )
}
export const CUserSearch = connect(
    (state) => ({ findedUsers: state.promise.findUsers?.payload || [] }),
    { onSearch: actionFindUsers }
)(UserSearch)
