import React, { useState, useEffect } from 'react'
import { connect } from 'react-redux'

import './ChatsPage.scss'
import { actionFullChatList, actionChatsCount } from '../../actions'
import { CChatList } from '../../components'

const ChatsPage = ({
    match: {
        params: { _id },
    },
    auth,
    getChats,
    chatsCount = 20,
    allCount,
    getAllCount,
}) => {
    const [chatBlock, setChatBlock] = useState(0)
    const [count, setCount] = useState(allCount)

    useEffect(async () => {
        const userId = auth.payload?.sub?.id
        if (userId) {
            await getChats(userId, chatBlock, chatsCount)

            const res = await getAllCount(userId)
            setCount(res)
        }

        return function cleanUp() {}
    }, [chatBlock])

    return (
        <div
            className="chatsPage"
            onScroll={(e) => {
                if (chatBlock < count) {
                    if (
                        e.target.scrollTop >=
                        e.target.scrollHeight - e.target.clientHeight
                    ) {
                        setChatBlock((chatBlock) => chatBlock + chatsCount)
                    }
                }
            }}
        >
            <CChatList currChatId={_id} />
        </div>
    )
}
export const CChatsPage = connect(
    (state) => ({
        auth: state.auth,
        allCount: state.promise?.chatsCount?.payload || 0,
    }),
    { getChats: actionFullChatList, getAllCount: actionChatsCount }
)(ChatsPage)
